# Gallery

## ASCII Art Animation

|  [Cherry Blossom Globe](./globe.md)  |
|  :--:  |
| <img src="https://raw.githubusercontent.com/charming-art/public-files/master/example_globe.gif" height="210px" alt="bar chart" />|

## Character-Style Generative Art

|  [Beating Heart](./heart.md)  |
|  :--:  |
| <img src="https://raw.githubusercontent.com/charming-art/public-files/master/example_heart.gif" height="210px" alt="bar chart" />|

## Terminal Game Application

|  [Eating Poetry](./snake.md)  |
|  :--:  |
| <img src="https://raw.githubusercontent.com/charming-art/public-files/master/example_snake.gif" height="210px" alt="bar chart" />|

## Expressive Data Visualization

|  [Covid-19 Bar Chart](./bar.md)  | [Hand Pie Chart](./pie.md) |
|  :--:  |  :--:  |
| <img src="https://raw.githubusercontent.com/charming-art/public-files/master/example_barchart.png" height="210px" alt="bar chart" />|<img src="https://raw.githubusercontent.com/charming-art/public-files/master/example_piechart.png" height="210px" alt="pie chart" />|

## Algorithm Visualization

| [BFS](./bfs.md) | [DFS](./dfs.md) | [Prim](./prim.md) |
|  :--:  |  :--:  |  :--:  |
| <img src="https://raw.githubusercontent.com/charming-art/public-files/master/example_bfs_preview.gif" height="210px" alt="bfs" />| <img src="https://raw.githubusercontent.com/charming-art/public-files/master/example_dfs_preview.gif" height="210px" alt="dfs" />| <img src="https://raw.githubusercontent.com/charming-art/public-files/master/example_prim_preview.gif" height="210px" alt="prim" />|

| [Bubble Sort](./bubble.md) | [Insertion Sort](./insertion.md) | [Merge Sort](./merge.md) |
|  :--:  |  :--:  |  :--:  |
| <img src="https://raw.githubusercontent.com/charming-art/public-files/master/example_bubble_preview.gif"  height="250px" alt="bubble" />| <img src="https://raw.githubusercontent.com/charming-art/public-files/master/example_insertion_preview.gif" height="250px"  alt="insertion" />| <img src="https://raw.githubusercontent.com/charming-art/public-files/master/example_merge_preview.gif" height="250px" alt="merge" />|